@@ -1,25 +1,28 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
-BEGIN {
-  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.5';
-}
-
-use Moose;
-use Moose::Autobox;
-use namespace::autoclean;
-with 'Dist::Zilla::Role::PluginBundle';
 
 # ABSTRACT: IDOPEREL's plugin bundle for Dist::Zilla.
 
+use Moose;
+use namespace::autoclean;
+
+with 'Dist::Zilla::Role::PluginBundle::Easy';
+
+our $VERSION = "0.700";
+$VERSION = eval $VERSION;
+
 use Dist::Zilla::PluginBundle::Filter;
 use Dist::Zilla::PluginBundle::Classic;
 use Dist::Zilla::PluginBundle::Git;
+use Dist::Zilla::Plugin::VersionFromModule;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::AutoPrereqs;
+use Dist::Zilla::Plugin::Prereqs;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::GithubMeta;
 use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::InstallGuide;
 use Dist::Zilla::Plugin::CheckChangesHasContent;
 use Dist::Zilla::Plugin::DistManifestTests;
 use Dist::Zilla::Plugin::Signature;
@@ -30,7 +33,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version 0.5
+version 0.700
 
 =head1 SYNOPSIS
 
@@ -49,12 +52,16 @@ This bundle provides the following plugins and bundles:
 	[@Filter]
 	-bundle = @Classic
 	-remove = Readme
+	-remove = PkgVersion
 
+	[@Git]
+
+	[VersionFromModule]
 	[AutoPrereqs]
 	[CheckChangesHasContent]
 	[DistManifestTests]
-	[@Git]
 	[GithubMeta]
+	[InstallGuide]
 	[MetaJSON]
 	[MinimumPerl]
 	[NextRelease]
@@ -64,49 +71,36 @@ This bundle provides the following plugins and bundles:
 
 =head1 INTERNAL METHODS
 
-=head2 bundle_config
+=head2 configure
 
 =cut
 
-sub bundle_config {
-	my ($self, $section) = @_;
-	my $class = ref($self) || $self;
+sub configure {
+	my $self = shift;
 
-	my $arg = $section->{payload};
+	$self->add_bundle(Filter => {
+		-bundle => '@Classic',
+		-remove => [qw/Readme PkgVersion/],
+	});
 
-	my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config(
-		{
-			name    => "$class/Classic",
-			payload => {
-				bundle => '@Classic',
-				remove => [qw/Readme/],
-			}
-		}
+	$self->add_bundle('Git');
+
+	$self->add_plugins(
+		'VersionFromModule',
+
+		[ 'AutoPrereqs' => { skip => $self->payload->{auto_prereqs_skip} } ],
+
+		'CheckChangesHasContent',
+		'DistManifestTests',
+		'GithubMeta',
+		'InstallGuide',
+		'MetaJSON',
+		'MinimumPerl',
+		'NextRelease',
+		'ReadmeFromPod',
+		'TestRelease',
+		'Signature'
 	);
-
-	# params
-
-	my $prefix = 'Dist::Zilla::Plugin::';
-	my @extra = map { [ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ] } (
-		[ AutoPrereqs			=> { skip  => $arg->{auto_prereqs_skip} } ],
-		[ MetaJSON			=> {} ],
-		[ MinimumPerl			=> {} ],
-		[ NextRelease			=> {} ],
-		[ ReadmeFromPod			=> {} ],
-		[ CheckChangesHasContent	=> {} ],
-		[ DistManifestTests		=> {} ],
-		[ TestRelease			=> {} ],
-		[ Signature			=> {} ],
-	);
-
-	push (@plugins, @extra);
-
-	# add git plugins
-	push (@plugins,	Dist::Zilla::PluginBundle::Git->bundle_config({ name => "$section->{name}/Git",	payload => {} }));
-
-	eval "require $_->[1]; 1;" or die for @plugins; ## no critic Carp
-
-	return @plugins;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -148,13 +142,9 @@ L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-IDOPEREL/>
 
 =back
 
-=head1 ACKNOWLEDGMENTS
-
-Based on L<Dist::Zilla::PluginBundle::PDONELAN> by Patrick Donelan.
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Ido Perlmuter.
+Copyright 2010-2011 Ido Perlmuter.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
